@@ -366,9 +366,9 @@ subroutine write_fits(realspec,fittedspectrum,continuum,skyspectrum,fittedlines,
   else
   call ftpcom(unit,"continuum fitting:                disabled",status)
   endif
-  write(writevalue,"(F5.2)") baddata
+  write(writevalue,"(F8.2)") baddata
   call ftpcom(unit,"spectrum fitted if max value >    "//writevalue,status)
-  write(writevalue,"(F5.2)") wavelengthscaling
+  write(writevalue,"(F8.2)") wavelengthscaling
   call ftpcom(unit,"Angstroms per wavelength unit:    "//writevalue,status)
   if (tablewavelengthcolumn.ne.1) then
   write(writevalue,"(I2)") tablewavelengthcolumn
@@ -430,11 +430,11 @@ subroutine write_fits(realspec,fittedspectrum,continuum,skyspectrum,fittedlines,
 
   if (status .gt. 0) then
     call ftgerr(status,cfitsioerror)
-    print *,gettime(),"CFITSIO error: ",status,cfitsioerror
+    print *,gettime(),"[107] CFITSIO error: ",status,cfitsioerror
     print *,gettime(),"thread ",threadnumber,", unit ",unit
     call exit(107)
   else
-    print *,gettime(),"Wrote fit to header FIT of output file ",trim(outputdirectory)//trim(outputbasename)//"_fit.fits"
+    print *,gettime(),"Wrote fit to extension FIT of output file ",trim(outputdirectory)//trim(outputbasename)//"_fit.fits"
   endif
 
 ! second extension for the lines
@@ -536,10 +536,10 @@ subroutine write_fits(realspec,fittedspectrum,continuum,skyspectrum,fittedlines,
 
   if (status .gt. 0) then
     call ftgerr(status,cfitsioerror)
-    print *,gettime(),"CFITSIO error: ",status,cfitsioerror
+    print *,gettime(),"[107] CFITSIO error: ",status,cfitsioerror
     call exit(107)
   else
-    print *,gettime(),"Wrote line list to header LINES"
+    print *,gettime(),"Wrote line list to extension LINES"
   endif
 
 ! third extension for nlines, f(hb), rv, resolution
@@ -559,6 +559,14 @@ subroutine write_fits(realspec,fittedspectrum,continuum,skyspectrum,fittedlines,
   call ftpcle(unit,3,1,1,1,(/c*(redshiftguess_overall-1)/),status)
   call ftpcle(unit,4,1,1,1,(/resolutionguess/),status)
 
+  if (status .gt. 0) then
+    call ftgerr(status,cfitsioerror)
+    print *,gettime(),"[107] CFITSIO error: ",status,cfitsioerror
+    call exit(107)
+  else
+    print *,gettime(),"Wrote QC info to extension QC"
+  endif
+
 ! close
 
   call ftclos(unit, status)
