@@ -127,7 +127,6 @@ else
   redshiftguess_overall = fittedlines(1)%redshift ! when fitting chunks, use this redshift to get lines in the right range from the catalogue. if velocity from each chunk is used, then there's a chance that a line could be missed or double counted due to variations in the calculated velocity between chunks.
   redshiftguess=fittedlines(1)%redshift
   resolutionguess=fittedlines(1)%resolution
-
   deallocate(stronglines)
 
 endif
@@ -141,11 +140,17 @@ if (redshiftguess_overall.eq.0.0) redshiftguess_overall=1.0 ! todo: sort this ou
 call selectlines(deeplines_catalogue, realspec(1)%wavelength/redshiftguess_overall, realspec(size(realspec))%wavelength/redshiftguess_overall, fittedlines, totallines)
 
 if (totallines .eq. 0) then
-  print *,gettime(),"Error: no known emission lines in this spectrum."
-  print *,gettime(),"       Are your wavelength units correct?  Default catalogues use Angstroms"
+  print *,gettime(),"[201] no known emission lines in this spectrum."
+  print *,gettime(),"      Are your wavelength units correct?  Default catalogues use Angstroms"
+  print *,gettime(),"      wavelength range is ",realspec(1)%wavelength/redshiftguess_overall,"-",realspec(size(realspec))%wavelength/redshiftguess_overall
   call exit(201)
 endif
 
+if (redshiftguess.eq.0.0 .and. resolutionguess.eq.0.0) then ! no strong lines were found to estimate the necessary parameters
+  print *,gettime(),"[202] no lines found to estimate the velocity and resolution"
+  call exit(202)
+endif
+
 if (messages) print *, gettime(),"fitting full spectrum with ",totallines," lines"
 
 ! process the spectrum so that it only contains line regions
